@@ -20,9 +20,13 @@ from trove.cmd.common import with_initialize
 
 @with_initialize
 def main(conf):
+    from trove.common import notification
     from trove.common.rpc import service as rpc_service
     from trove.common.rpc import version as rpc_version
+    from trove.instance import models as inst_models
 
+    notification.DBaaSAPINotification.register_notify_callback(
+        inst_models.persist_instance_fault)
     topic = conf.conductor_queue
     server = rpc_service.RpcService(
         manager=conf.conductor_manager, topic=topic,
