@@ -21,6 +21,7 @@ from trove.cluster.views import ClusterView
 from trove.common import cfg
 from trove.common import exception
 from trove.common import remote
+from trove.common import server_group as srv_grp
 from trove.common.strategies.cluster import base
 from trove.extensions.mgmt.clusters.views import MgmtClusterView
 from trove.instance import models as inst_models
@@ -49,14 +50,14 @@ class RedisCluster(models.Cluster):
 
     @staticmethod
     def _create_instances(context, db_info, datastore, datastore_version,
-                          instances):
+                          instances, extended_properties, locality):
         Redis_conf = CONF.get(datastore_version.manager)
         num_instances = len(instances)
         total_volume_allocation = 0
 
         # Validate and Cache flavors
         nova_client = remote.create_nova_client(context)
-        unique_flavors = set(map(lambda i: i['flavor_id'], instances))
+        unique_flavors = set(inst['flavor_id'] for inst in instances)
         flavor_cache = {}
         for fid in unique_flavors:
             try:
@@ -89,28 +90,29 @@ class RedisCluster(models.Cluster):
         check_quotas(context.tenant, quota_request)
 
         # Creating member instances
-        return map(lambda instance:
-                   inst_models.Instance.create(context,
-                                               instance['name'],
-                                               instance['flavor_id'],
-                                               datastore_version.image_id,
-                                               [], [],
-                                               datastore, datastore_version,
-                                               instance.get('volume_size'),
-                                               None,
-                                               instance.get(
-                                                   'availability_zone', None),
-                                               instance.get('nics', None),
-                                               configuration_id=None,
-                                               cluster_config={
-                                                   "id": db_info.id,
-                                                   "instance_type": "member"}
-                                               ),
-                   instances)
+        return [inst_models.Instance.create(context,
+                                            instance['name'],
+                                            instance['flavor_id'],
+                                            datastore_version.image_id,
+                                            [], [],
+                                            datastore, datastore_version,
+                                            instance.get('volume_size'),
+                                            None,
+                                            instance.get(
+                                                'availability_zone', None),
+                                            instance.get('nics', None),
+                                            configuration_id=None,
+                                            cluster_config={
+                                                "id": db_info.id,
+                                                "instance_type": "member"},
+                                            locality=locality,
+                                            modules=instance.get('modules')
+                                            )
+                for instance in instances]
 
     @classmethod
     def create(cls, context, name, datastore, datastore_version,
-               instances, extended_properties):
+               instances, extended_properties, locality):
         LOG.debug("Initiating cluster creation.")
 
         # Updating Cluster Task
@@ -121,7 +123,7 @@ class RedisCluster(models.Cluster):
             task_status=ClusterTasks.BUILDING_INITIAL)
 
         cls._create_instances(context, db_info, datastore, datastore_version,
-                              instances)
+                              instances, extended_properties, locality)
 
         # Calling taskmanager to further proceed for cluster-configuration
         task_api.load(context, datastore_version.manager).create_cluster(
@@ -141,9 +143,10 @@ class RedisCluster(models.Cluster):
 
         db_info.update(task_status=ClusterTasks.GROWING_CLUSTER)
 
+        locality = srv_grp.ServerGroup.convert_to_hint(self.server_group)
         new_instances = self._create_instances(context, db_info,
                                                datastore, datastore_version,
-                                               instances)
+                                               instances, None, locality)
 
         task_api.load(context, datastore_version.manager).grow_cluster(
             db_info.id, [instance.id for instance in new_instances])
@@ -180,10 +183,14 @@ class RedisCluster(models.Cluster):
             remain_insts = [inst_models.Instance.load(self.context, inst.id)
                             for inst in all_instances
                             if inst.id not in removal_ids]
-            map(lambda x: Cluster.get_guest(x).remove_nodes(node_ids),
-                remain_insts)
-            map(lambda x: x.update_db(cluster_id=None), removal_insts)
-            map(inst_models.Instance.delete, removal_insts)
+
+            for inst in remain_insts:
+                guest = Cluster.get_guest(inst)
+                guest.remove_nodes(node_ids)
+            for inst in removal_insts:
+                inst.update_db(cluster_id=None)
+            for inst in removal_insts:
+                inst_models.Instance.delete(inst)
 
             return RedisCluster(self.context, cluster_info,
                                 self.ds, self.ds_version)
