@@ -24,6 +24,9 @@ import six
 import uuid
 
 from oslo_log import log as logging
+from oslo_utils import encodeutils
+from pymysql import err as pymysql_err
+from six.moves import urllib
 import sqlalchemy
 from sqlalchemy import exc
 from sqlalchemy import interfaces
@@ -47,6 +50,7 @@ from trove.guestagent.db import models
 from trove.guestagent import pkg
 
 ADMIN_USER_NAME = "os_admin"
+CONNECTION_STR_FORMAT = "mysql+pymysql://%s:%s@127.0.0.1:3306"
 LOG = logging.getLogger(__name__)
 FLUSH = text(sql_query.FLUSH)
 ENGINE = None
@@ -255,8 +259,8 @@ class BaseMySqlAdmin(object):
                 user = models.MySQLUser()
                 user.deserialize(user_dict)
                 LOG.debug("\tDeserialized: %s." % user.__dict__)
-                uu = sql_query.UpdateUser(user.name, host=user.host,
-                                          clear=user.password)
+                uu = sql_query.SetPassword(user.name, host=user.host,
+                                           new_password=user.password)
                 t = text(str(uu))
                 client.execute(t)
 
@@ -264,33 +268,28 @@ class BaseMySqlAdmin(object):
         """Change the attributes of an existing user."""
         LOG.debug("Changing user attributes for user %s." % username)
         user = self._get_user(username, hostname)
-        db_access = set()
-        grantee = set()
-        with self.local_sql_client(self.mysql_app.get_engine()) as client:
-            q = sql_query.Query()
-            q.columns = ["grantee", "table_schema"]
-            q.tables = ["information_schema.SCHEMA_PRIVILEGES"]
-            q.group = ["grantee", "table_schema"]
-            q.where = ["privilege_type != 'USAGE'"]
-            t = text(str(q))
-            db_result = client.execute(t)
-            for db in db_result:
-                grantee.add(db['grantee'])
-                if db['grantee'] == "'%s'@'%s'" % (user.name, user.host):
-                    db_name = db['table_schema']
-                    db_access.add(db_name)
-        with self.local_sql_client(self.mysql_app.get_engine()) as client:
-            uu = sql_query.UpdateUser(user.name, host=user.host,
-                                      clear=user_attrs.get('password'),
-                                      new_user=user_attrs.get('name'),
-                                      new_host=user_attrs.get('host'))
-            t = text(str(uu))
-            client.execute(t)
-            uname = user_attrs.get('name') or username
-            host = user_attrs.get('host') or hostname
-            find_user = "'%s'@'%s'" % (uname, host)
-            if find_user not in grantee:
-                self.grant_access(uname, host, db_access)
+
+        new_name = user_attrs.get('name')
+        new_host = user_attrs.get('host')
+        new_password = user_attrs.get('password')
+
+        if new_name or new_host or new_password:
+
+            with self.local_sql_client(self.mysql_app.get_engine()) as client:
+
+                if new_password is not None:
+                    uu = sql_query.SetPassword(user.name, host=user.host,
+                                               new_password=new_password)
+
+                    t = text(str(uu))
+                    client.execute(t)
+
+                if new_name or new_host:
+                    uu = sql_query.RenameUser(user.name, host=user.host,
+                                              new_user=new_name,
+                                              new_host=new_host)
+                    t = text(str(uu))
+                    client.execute(t)
 
     def create_database(self, databases):
         """Create the list of specified databases."""
@@ -362,13 +361,14 @@ class BaseMySqlAdmin(object):
             user.name = username  # Could possibly throw a BadRequest here.
         except ValueError as ve:
             LOG.exception(_("Error Getting user information"))
+            err_msg = encodeutils.exception_to_unicode(ve)
             raise exception.BadRequest(_("Username %(user)s is not valid"
                                          ": %(reason)s") %
-                                       {'user': username, 'reason': ve.message}
+                                       {'user': username, 'reason': err_msg}
                                        )
         with self.local_sql_client(self.mysql_app.get_engine()) as client:
             q = sql_query.Query()
-            q.columns = ['User', 'Host', 'Password']
+            q.columns = ['User', 'Host']
             q.tables = ['mysql.user']
             q.where = ["Host != 'localhost'",
                        "User = '%s'" % username,
@@ -380,7 +380,6 @@ class BaseMySqlAdmin(object):
             if len(result) != 1:
                 return None
             found_user = result[0]
-            user.password = found_user['Password']
             user.host = found_user['Host']
             self._associate_dbs(user)
             return user
@@ -463,7 +462,7 @@ class BaseMySqlAdmin(object):
                 mysql_db.collate = database[2]
                 databases.append(mysql_db.serialize())
         LOG.debug("databases = " + str(databases))
-        if database_names.rowcount <= limit:
+        if limit is not None and database_names.rowcount <= limit:
             next_marker = None
         return databases, next_marker
 
@@ -527,7 +526,7 @@ class BaseMySqlAdmin(object):
                 self._associate_dbs(mysql_user)
                 next_marker = row['Marker']
                 users.append(mysql_user.serialize())
-        if result.rowcount <= limit:
+        if limit is not None and result.rowcount <= limit:
             next_marker = None
         LOG.debug("users = " + str(users))
 
@@ -570,6 +569,14 @@ class BaseKeepAliveConnection(interfaces.PoolListener):
                 raise exc.DisconnectionError()
             else:
                 raise
+        # MariaDB seems to timeout the client in a different
+        # way than MySQL and PXC, which manifests itself as
+        # an invalid packet sequence.  Handle it as well.
+        except pymysql_err.InternalError as ex:
+            if "Packet sequence number wrong" in ex.message:
+                raise exc.DisconnectionError()
+            else:
+                raise
 
 
 @six.add_metaclass(abc.ABCMeta)
@@ -587,10 +594,14 @@ class BaseMySqlApp(object):
     def keep_alive_connection_cls(self):
         return self._keep_alive_connection_cls
 
+    @property
+    def service_candidates(self):
+        return ["mysql", "mysqld", "mysql-server"]
+
     @property
     def mysql_service(self):
-        MYSQL_SERVICE_CANDIDATES = ["mysql", "mysqld", "mysql-server"]
-        return operating_system.service_discovery(MYSQL_SERVICE_CANDIDATES)
+        service_candidates = self.service_candidates
+        return operating_system.service_discovery(service_candidates)
 
     configuration_manager = ConfigurationManager(
         MYSQL_CONFIG, MYSQL_OWNER, MYSQL_OWNER, CFG_CODEC, requires_root=True,
@@ -606,13 +617,11 @@ class BaseMySqlApp(object):
             return ENGINE
 
         pwd = self.get_auth_password()
-        ENGINE = sqlalchemy.create_engine("mysql://%s:%s@localhost:3306" %
-                                          (ADMIN_USER_NAME, pwd.strip()),
-                                          pool_recycle=7200,
-                                          echo=CONF.sql_query_logging,
-                                          listeners=[
-                                              self.keep_alive_connection_cls()]
-                                          )
+        ENGINE = sqlalchemy.create_engine(
+            CONNECTION_STR_FORMAT % (ADMIN_USER_NAME,
+                                     urllib.parse.quote(pwd.strip())),
+            pool_recycle=120, echo=CONF.sql_query_logging,
+            listeners=[self.keep_alive_connection_cls()])
         return ENGINE
 
     @classmethod
@@ -647,18 +656,21 @@ class BaseMySqlApp(object):
         Create a os_admin user with a random password
         with all privileges similar to the root user.
         """
+        LOG.debug("Creating Trove admin user '%s'." % ADMIN_USER_NAME)
         localhost = "localhost"
         g = sql_query.Grant(permissions='ALL', user=ADMIN_USER_NAME,
                             host=localhost, grant_option=True, clear=password)
         t = text(str(g))
         client.execute(t)
+        LOG.debug("Trove admin user '%s' created." % ADMIN_USER_NAME)
 
     @staticmethod
     def _generate_root_password(client):
         """Generate and set a random root password and forget about it."""
         localhost = "localhost"
-        uu = sql_query.UpdateUser("root", host=localhost,
-                                  clear=utils.generate_random_password())
+        uu = sql_query.SetPassword(
+            "root", host=localhost,
+            new_password=utils.generate_random_password())
         t = text(str(uu))
         client.execute(t)
 
@@ -679,20 +691,26 @@ class BaseMySqlApp(object):
         self.start_mysql()
 
     def secure(self, config_contents):
-        LOG.info(_("Generating admin password."))
-        admin_password = utils.generate_random_password()
+        LOG.debug("Securing MySQL now.")
         clear_expired_password()
-        engine = sqlalchemy.create_engine("mysql://root:@localhost:3306",
-                                          echo=True)
-        with self.local_sql_client(engine) as client:
-            self._remove_anonymous_user(client)
+        LOG.debug("Generating admin password.")
+        admin_password = utils.generate_random_password()
+        engine = sqlalchemy.create_engine(
+            CONNECTION_STR_FORMAT % ('root', ''), echo=True)
+        with self.local_sql_client(engine, use_flush=False) as client:
             self._create_admin_user(client, admin_password)
 
-        self.stop_db()
+        LOG.debug("Switching to the '%s' user now." % ADMIN_USER_NAME)
+        engine = sqlalchemy.create_engine(
+            CONNECTION_STR_FORMAT % (ADMIN_USER_NAME,
+                                     urllib.parse.quote(admin_password)),
+            echo=True)
+        with self.local_sql_client(engine) as client:
+            self._remove_anonymous_user(client)
 
+        self.stop_db()
         self._reset_configuration(config_contents, admin_password)
         self.start_mysql()
-
         LOG.debug("MySQL secure complete.")
 
     def _reset_configuration(self, configuration, admin_password=None):
@@ -773,12 +791,16 @@ class BaseMySqlApp(object):
             raise RuntimeError("Could not stop MySQL!")
 
     def _remove_anonymous_user(self, client):
+        LOG.debug("Removing anonymous user.")
         t = text(sql_query.REMOVE_ANON)
         client.execute(t)
+        LOG.debug("Anonymous user removed.")
 
     def _remove_remote_root_access(self, client):
+        LOG.debug("Removing root access.")
         t = text(sql_query.REMOVE_ROOT)
         client.execute(t)
+        LOG.debug("Root access removed.")
 
     def restart(self):
         try:
@@ -802,7 +824,7 @@ class BaseMySqlApp(object):
         LOG.debug("Applying overrides to MySQL.")
         with self.local_sql_client(self.get_engine()) as client:
             LOG.debug("Updating override values in running MySQL.")
-            for k, v in overrides.iteritems():
+            for k, v in overrides.items():
                 byte_value = guestagent_utils.to_bytes(v)
                 q = sql_query.SetServerVariable(key=k, value=byte_value)
                 t = text(str(q))
@@ -960,7 +982,7 @@ class BaseMySqlApp(object):
             # but actually come up ok. we're looking into the timing issue on
             # parallel, but for now, we'd like to give it one more chance to
             # come up. so regardless of the execute_with_timeout() response,
-            # we'll assume mysql comes up and check it's status for a while.
+            # we'll assume mysql comes up and check its status for a while.
             pass
         if not self.status.wait_for_real_status_to_change_to(
                 rd_instance.ServiceStatuses.RUNNING,
@@ -1037,14 +1059,14 @@ class BaseMySqlRootAccess(object):
                 cu = sql_query.CreateUser(user.name, host=user.host)
                 t = text(str(cu))
                 client.execute(t, **cu.keyArgs)
-            except exc.OperationalError as err:
+            except (exc.OperationalError, exc.InternalError) as err:
                 # Ignore, user is already created, just reset the password
                 # TODO(rnirmal): More fine grained error checking later on
                 LOG.debug(err)
         with self.local_sql_client(self.mysql_app.get_engine()) as client:
             print(client)
-            uu = sql_query.UpdateUser(user.name, host=user.host,
-                                      clear=user.password)
+            uu = sql_query.SetPassword(user.name, host=user.host,
+                                       new_password=user.password)
             t = text(str(uu))
             client.execute(t)
 
