@@ -30,6 +30,7 @@ from oslo_log import log as logging
 
 from trove.common import cfg
 from trove.common.i18n import _
+from trove.common import utils
 
 
 LOG = logging.getLogger(__name__)
@@ -67,24 +68,8 @@ def get_custom_managers():
 
 
 def datastore_registry():
-    return dict(chain(defaults.iteritems(),
-                get_custom_managers().iteritems()))
-
-
-def to_gb(bytes):
-    if bytes == 0:
-        return 0.0
-    size = bytes / 1024.0 ** 3
-    # Make sure we don't return 0.0 if the size is greater than 0
-    return max(round(size, 2), 0.01)
-
-
-def to_mb(bytes):
-    if bytes == 0:
-        return 0.0
-    size = bytes / 1024.0 ** 2
-    # Make sure we don't return 0.0 if the size is greater than 0
-    return max(round(size, 2), 0.01)
+    return dict(chain(defaults.items(),
+                get_custom_managers().items()))
 
 
 def get_filesystem_volume_stats(fs_path):
@@ -97,8 +82,8 @@ def get_filesystem_volume_stats(fs_path):
     total = stats.f_blocks * stats.f_bsize
     free = stats.f_bfree * stats.f_bsize
     # return the size in GB
-    used_gb = to_gb(total - free)
-    total_gb = to_gb(total)
+    used_gb = utils.to_gb(total - free)
+    total_gb = utils.to_gb(total)
 
     output = {
         'block_size': stats.f_bsize,
