@@ -92,6 +92,9 @@ class InstanceDetailView(InstanceView):
         result['instance']['datastore']['version'] = (self.instance.
                                                       datastore_version.name)
 
+        if self.instance.fault:
+            result['instance']['fault'] = self._build_fault_info()
+
         if self.instance.slaves:
             result['instance']['replicas'] = self._build_slaves_info()
 
@@ -99,6 +102,9 @@ class InstanceDetailView(InstanceView):
             result['instance']['configuration'] = (self.
                                                    _build_configuration_info())
 
+        if self.instance.locality:
+            result['instance']['locality'] = self.instance.locality
+
         if (isinstance(self.instance, models.DetailInstance) and
                 self.instance.volume_used):
             used = self.instance.volume_used
@@ -119,6 +125,13 @@ class InstanceDetailView(InstanceView):
 
         return result
 
+    def _build_fault_info(self):
+        return {
+            "message": self.instance.fault.message,
+            "created": self.instance.fault.updated,
+            "details": self.instance.fault.details,
+        }
+
     def _build_slaves_info(self):
         data = []
         for slave in self.instance.slaves:
