@@ -18,6 +18,7 @@
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import importutils
+import six
 
 from trove.common import exception
 from trove.common.i18n import _
@@ -229,7 +230,7 @@ class QuotaEngine(object):
 
         if not quota_driver_class:
             quota_driver_class = CONF.quota_driver
-        if isinstance(quota_driver_class, basestring):
+        if isinstance(quota_driver_class, six.string_types):
             quota_driver_class = importutils.import_object(quota_driver_class,
                                                            self._resources)
         self._driver = quota_driver_class
@@ -273,6 +274,15 @@ class QuotaEngine(object):
         return self._driver.get_all_quotas_by_tenant(tenant_id,
                                                      self._resources)
 
+    def get_all_quota_usages_by_tenant(self, tenant_id):
+        """Retrieve the quota usages for the given tenant.
+
+        :param tenant_id: The ID of the tenant to return quota usages for.
+        """
+
+        return self._driver.get_all_quota_usages_by_tenant(tenant_id,
+                                                           self._resources)
+
     def check_quotas(self, tenant_id, **deltas):
         self._driver.check_quotas(tenant_id, self._resources, deltas)
 
