@@ -141,6 +141,7 @@ class TestClusterController(trove_testtools.TestCase):
                 'volume_type': None,
                 'flavor_id': '1234',
                 'availability_zone': 'az',
+                'modules': None,
                 'nics': [
                     {'net-id': 'e89aa5fd-6b0a-436d-a75c-1545d34d5331'}
                 ]
@@ -157,7 +158,7 @@ class TestClusterController(trove_testtools.TestCase):
         self.controller.create(req, body, tenant_id)
         mock_cluster_create.assert_called_with(context, 'products',
                                                datastore, datastore_version,
-                                               instances, {})
+                                               instances, {}, None)
 
     @patch.object(Cluster, 'load')
     def test_show_cluster(self,
